@@ -5,7 +5,7 @@ use warnings FATAL => 'all';
 
 use Hash::Merge qw(_merge_hashes);
 
-our $VERSION = '0.04'; # Don't forget to change in pod below
+our $VERSION = '0.05'; # Don't forget to change in pod below
 
 use constant L_ADDITIVE => {
     'SCALAR' => {
@@ -43,7 +43,7 @@ use constant R_ADDITIVE => {
     },
 };
 
-use constant L_JSON_MERGE_PATCH => {
+use constant L_MERGE_PATCH => {
     'SCALAR' => {
         'SCALAR' => sub { $_[0] },
         'ARRAY'  => sub { $_[0] },
@@ -70,7 +70,7 @@ use constant L_JSON_MERGE_PATCH => {
     },
 };
 
-use constant R_JSON_MERGE_PATCH => {
+use constant R_MERGE_PATCH => {
     'SCALAR' => {
         'SCALAR' => sub { $_[1] },
         'ARRAY'  => sub { $_[1] },
@@ -171,12 +171,12 @@ use constant R_REPLACE => {
 
 my %INDEX = (
     L_ADDITIVE              => L_ADDITIVE,
-    L_JSON_MERGE_PATCH      => L_JSON_MERGE_PATCH,
+    L_MERGE_PATCH           => L_MERGE_PATCH,
     L_OVERRIDE              => L_OVERRIDE,
     L_REPLACE               => L_REPLACE,
 
     R_ADDITIVE              => R_ADDITIVE,
-    R_JSON_MERGE_PATCH      => R_JSON_MERGE_PATCH,
+    R_MERGE_PATCH           => R_MERGE_PATCH,
     R_OVERRIDE              => R_OVERRIDE,
     R_REPLACE               => R_REPLACE,
 );
@@ -211,7 +211,7 @@ Hash::Merge::Extra - Collection of extra behaviors for L<Hash::Merge>
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =head1 SYNOPSIS
 
@@ -247,11 +247,11 @@ Only specified behaviors registered if list defined:
 Hashes merged, arrays joined, undefined scalars overrided. Left and right
 precedence.
 
-=item B<L_JSON_MERGE_PATCH>, B<R_JSON_MERGE_PATCH>
+=item B<L_MERGE_PATCH>, B<R_MERGE_PATCH>
 
-JSON Merge Patch (L<rfc7386|https://tools.ietf.org/html/rfc7386>) behavior
-implementation for perl structures. Almost the same as C<L_OVERRIDE> and
-C<R_OVERRIDE>, but hash keys with undef values in the patch cause removal of
+JSON Merge Patch (L<rfc7386|https://tools.ietf.org/html/rfc7386>) patch
+behavior for perl structures. Almost the same as C<L_OVERRIDE> and
+C<R_OVERRIDE>, but hash keys with C<undef> values in the patch cause removal of
 existing keys in the main structure. Left and right precedence.
 
 =item B<L_OVERRIDE>, B<R_OVERRIDE>
